# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BiologicallyDerivedProductDispense',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('preparation', 'Preparation'), ('in-person', 'In Person'), ('allocated', 'Allocated'), ('issued', 'Issued'), ('unfulfilled', 'Unfulfilled'), ('returned', 'Returned'), ('entered-in-error', 'Entered in Error'), ('unknown', 'Unknown')], max_length=255, null=True)),
                ('prepared_date', models.DateTimeField(null=True)),
                ('when_handed_over', models.DateTimeField(null=True)),
                ('usage_instruction', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BiologicallyDerivedProductDispensePerformer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BiologicallyDerivedProductDispenseReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('groups', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingselections', '0002_initial'),
        ('medications', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('specimens', '0001_initial'),
        ('substances', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='imagingselectionbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='image_selection_based_on', to='imagingselections.imagingselectionbasedonreference'),
        ),
        migrations.AddField(
            model_name='imagingselectioncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='image_region_3d',
            field=models.ManyToManyField(blank=True, related_name='image_selection_image_region_3d', to='imagingselections.imagingselectionimageregion3d'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='instance',
            field=models.ManyToManyField(blank=True, related_name='image_selection_instance', to='imagingselections.imagingselectioninstance'),
        ),
        migrations.AddField(
            model_name='imagingselectioninstance',
            name='imaging_region_2d',
            field=models.ManyToManyField(blank=True, related_name='image_selection_instance_imaging_region_2d', to='imagingselections.imagingselectioninstanceimagingregion2d'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='image_selection_performer', to='imagingselections.imagingselectionperformer'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_care_team', to='careteams.careteamreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='imagingselectionperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_performer_actor', to='imagingselections.imagingselectionperformeractorreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionreference',
            name='image_selection',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_reference_image_selection', to='imagingselections.imagingselection'),
        ),
        migrations.AddField(
            model_name='imagingselectioncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_codeable_reference_reference', to='imagingselections.imagingselectionreference'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='focus',
            field=models.ManyToManyField(blank=True, related_name='imaging_selection_focus', to='imagingselections.imagingselectionreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_specimen', to='specimens.specimen'),
        ),
        migrations.AddField(
            model_name='imagingselectionsubjectreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_selection_subject_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='imagingselection',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='image_selection_subject', to='imagingselections.imagingselectionsubjectreference'),
        ),
    ]



"""Account choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class AccountStatus(models.TextChoices):
    """Account status choices."""

    ACTIVE = "active", _("Active")
    INACTIVE = "inactive", _("Inactive")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")
    ON_HOLD = "on-hold", _("On Hold")
    UNKNOWN = "unknown", _("Unknown")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.contrib.postgres.fields
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0002_initial'),
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChargeItemEntererReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemPerformer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemPerformerActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemProductCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemProductReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemReasonCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemServiceCodealbeReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItemServiceReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CharItemReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ChargeItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('definition_uri', django.contrib.postgres.fields.ArrayField(base_field=models.URLField(null=True), null=True, size=None)),
                ('status', models.CharField(choices=[('planned', 'Planned'), ('billable', 'Billable'), ('not-billable', 'Not Billable'), ('aborted', 'Aborted'), ('billed', 'Billed'), ('entered-in-error', 'Entered in Error'), ('unknown', 'Unknown')], max_length=255, null=True)),
                ('occurrence_date_time', models.DateTimeField(null=True)),
                ('entered_date', models.DateTimeField(null=True)),
                ('account', models.ManyToManyField(blank=True, related_name='charge_item_account', to='accounts.accountreference')),
                ('body_site', models.ManyToManyField(blank=True, related_name='charge_item_body_site', to='base.codeableconcept')),
                ('code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_code', to='base.codeableconcept')),
                ('cost_center', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_cost_center', to='base.organizationreference')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('chargeitems', '0003_initial'),
        ('conditions', '0004_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('imagingstudies', '0001_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0002_initial'),
        ('medicationadministrations', '0003_initial'),
        ('medicationdispenses', '0002_initial'),
        ('medicationrequests', '0002_initial'),
        ('medications', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('substances', '0001_initial'),
        ('supplydeliveries', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='chargeitementererreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_enterer', to='chargeitems.chargeitementererreference'),
        ),
        migrations.AddField(
            model_name='chargeitemperformer',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='charge_item_performer', to='chargeitems.chargeitemperformer'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='chargeitemperformeractorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='chargeitemperformer',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_performer_actor', to='chargeitems.chargeitemperformeractorreference'),
        ),
        migrations.AddField(
            model_name='chargeitemproductcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='product',
            field=models.ManyToManyField(blank=True, related_name='charge_item_product', to='chargeitems.chargeitemproductcodeablereference'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='chargeitemproductreference',
            name='substance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_reference_substance', to='substances.substance'),
        ),
        migrations.AddField(
            model_name='chargeitemproductcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_product_codeable_reference_reference', to='chargeitems.chargeitemproductreference'),
        ),
        migrations.AddField(
            model_name='chargeitemreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='charge_item_reason', to='chargeitems.chargeitemreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='immunization_recommendation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_immunization_recommendation', to='immunizationrecommendations.immunizationrecommendation'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='chargeitemreasonreference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitemreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reason_codeable_reference_reference', to='chargeitems.chargeitemreasonreference'),
        ),
        migrations.AddField(
            model_name='chargeitemservicecodealbereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='service',
            field=models.ManyToManyField(blank=True, related_name='charge_item_service', to='chargeitems.chargeitemservicecodealbereference'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='imaging_study',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_imaging_study', to='imagingstudies.imagingstudy'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_administration',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_administration', to='medicationadministrations.medicationadministration'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_dispense',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_dispense', to='medicationdispenses.medicationdispense'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='chargeitemservicereference',
            name='supply_delivery',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_reference_supply_delivery', to='supplydeliveries.supplydelivery'),
        ),
        migrations.AddField(
            model_name='chargeitemservicecodealbereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_service_codeable_reference_reference', to='chargeitems.chargeitemservicereference'),
        ),
        migrations.AddField(
            model_name='charitemreference',
            name='charge_item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reference_charge_item', to='chargeitems.chargeitem'),
        ),
        migrations.AddField(
            model_name='charitemreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='charge_item_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='chargeitem',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='charge_item_reference_part_of', to='chargeitems.charitemreference'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0004_initial'),
        ('groups', '0003_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0003_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('provenances', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TransportBasedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_identifier', to='base.identifier')),
                ('medication_request', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_medication_request', to='medicationrequests.medicationrequest')),
                ('service_request', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_service_request', to='servicerequests.servicerequest')),
                ('vision_prescription', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_based_on_vision_prescription', to='visionprescriptions.visionprescription')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TransportInput',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value', models.CharField(max_length=255, null=True)),
                ('type', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_input_type', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TransportOutput',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('value', models.CharField(max_length=255, null=True)),
                ('type', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_output_type', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TransportOwnerReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('care_team', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_care_team', to='careteams.careteam')),
                ('device', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_device', to='devices.device')),
                ('healthcare_service', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_healthcare_service', to='healthcareservices.healthcareservice')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_organization', to='organizations.organization')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_patient', to='patients.patient')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_practitioner_role', to='practitionerroles.practitionerrole')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner_reference_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Transport',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('preparation', 'Preparation'), ('in-progress', 'In Progress'), ('not-done', 'Not Done'), ('suspended', 'Suspended'), ('stopped', 'Stopped'), ('on-hold', 'On Hold'), ('completed', 'Completed'), ('entered-in-error', 'Entered in Error'), ('unknown', 'Unknown')], max_length=255, null=True)),
                ('description', models.TextField(null=True)),
                ('completion_time', models.DateTimeField(null=True)),
                ('authored_on', models.DateTimeField(null=True)),
                ('last_modified', models.DateTimeField(null=True)),
                ('code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_code', to='base.codeableconcept')),
                ('current_location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_current_location', to='locations.locationreference')),
                ('encounter', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_encounter', to='encounters.encounterreference')),
                ('focus', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_focus', to='base.reference')),
                ('for_value', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_for_value', to='base.reference')),
                ('group_identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_group_identifier', to='base.identifier')),
                ('identifier', models.ManyToManyField(blank=True, related_name='transport_identifier', to='base.identifier')),
                ('location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_location', to='locations.locationreference')),
                ('note', models.ManyToManyField(blank=True, related_name='transport_note', to='base.annotation')),
                ('performer_type', models.ManyToManyField(blank=True, related_name='transport_performer_type', to='base.codeableconcept')),
                ('reason', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_reason', to='base.codeablereference')),
                ('relevant_history', models.ManyToManyField(blank=True, related_name='transport_relevant_history', to='provenances.provenancereference')),
                ('requested_location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requested_location', to='locations.locationreference')),
                ('status_reason', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_status_reason', to='base.codeableconcept')),
                ('based_on', models.ManyToManyField(blank=True, related_name='transport_based_on', to='transports.transportbasedonreference')),
                ('input', models.ManyToManyField(blank=True, related_name='transport_input', to='transports.transportinput')),
                ('output', models.ManyToManyField(blank=True, related_name='transport_output', to='transports.transportoutput')),
                ('owner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_owner', to='transports.transportownerreference')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TransportReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_reference_identifier', to='base.identifier')),
                ('transport', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_reference_transport', to='transports.transport')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='transport',
            name='history',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_history', to='transports.transportreference'),
        ),
        migrations.AddField(
            model_name='transport',
            name='part_of',
            field=models.ManyToManyField(blank=True, related_name='transport_part_of', to='transports.transportreference'),
        ),
        migrations.CreateModel(
            name='TransportRequesterReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('device', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_device', to='devices.device')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_organization', to='organizations.organization')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_patient', to='patients.patient')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_practitioner_role', to='practitionerroles.practitionerrole')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='transport',
            name='requester',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_requester', to='transports.transportrequesterreference'),
        ),
        migrations.CreateModel(
            name='TransportRestriction',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('repetitions', models.PositiveIntegerField(null=True)),
                ('period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_period', to='base.period')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='transport',
            name='restriction',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction', to='transports.transportrestriction'),
        ),
        migrations.CreateModel(
            name='TransportRestrictionRecipientReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('group', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_group', to='groups.group')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_organization', to='organizations.organization')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_patient', to='patients.patient')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_practitioner_role', to='practitionerroles.practitionerrole')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='transport_restriction_recipient_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='transportrestriction',
            name='recipient',
            field=models.ManyToManyField(blank=True, related_name='transport_restriction_recipient', to='transports.transportrestrictionrecipientreference'),
        ),
    ]



"""Schedule serializers."""

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    PeriodSerializer,
)
from dfhir.healthcareservices.serializers import (
    HealthCareServiceCodeableReferenceSerializer,
)
from dfhir.schedules.models import Schedule, ScheduleReference, SchedulesActorReference


class ActorSerializer(BaseReferenceModelSerializer):
    """Actor serializer."""

    class Meta:
        """Meta class."""

        model = SchedulesActorReference
        exclude = ["created_at", "updated_at"]


class ScheduleSerializer(BaseWritableNestedModelSerializer):
    """Schedule serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    actor = ActorSerializer(many=True, required=True)
    planning_horizon = PeriodSerializer(many=False, required=False)
    service_type = HealthCareServiceCodeableReferenceSerializer(
        many=True, required=False
    )
    specialty = CodeableConceptSerializer(many=True, required=False)
    service_category = CodeableConceptSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = Schedule
        exclude = ["created_at", "updated_at"]

    # TODO: This needs to be moved
    # def validate(self, data):
    #     """Validate data."""
    #     validate_date_time_fields(
    #         data.get("start_date_time"), data.get("end_date_time")
    #     )
    #     return data


class ScheduleReferenceSerializer(BaseReferenceModelSerializer):
    """Schedule reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ScheduleReference
        exclude = ["created_at", "updated_at"]



"""Coverage serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    MoneySerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
    SimpleQuantitySerializer,
)
from dfhir.contracts.serializers import ContractReferenceSerializer
from dfhir.patients.serializers import (
    PatientReferenceSerializer,
    PatientRelatedPersonReferenceSerializer,
)

from .models import (
    Coverage,
    CoverageClaimResponseReference,
    CoverageClass,
    CoverageCostToBeneficiary,
    CoverageCostToBeneficiaryException,
    CoveragePaymentBy,
    CoveragePaymentByPartyReference,
    CoveragePolicyHolderReference,
    CoverageReference,
)


class CoveragePolicyHolderReferenceSerializer(BaseReferenceModelSerializer):
    """Policy Holder Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = CoveragePolicyHolderReference
        exclude = ["created_at", "updated_at"]


class CoveragePaymentByPartyReferenceSerializer(BaseReferenceModelSerializer):
    """Coverage By Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = CoveragePaymentByPartyReference
        exclude = ["created_at", "updated_at"]


class CoveragePaymentBySerializer(WritableNestedModelSerializer):
    """Coverage Payment By Serializer."""

    party = CoveragePaymentByPartyReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = CoveragePaymentBy
        exclude = ["created_at", "updated_at"]


class CoverageCostToBeneficiaryExceptionSerializer(WritableNestedModelSerializer):
    """Coverage Cost To Beneficiary Exception Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    period = PeriodSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = CoverageCostToBeneficiaryException
        exclude = ["created_at", "updated_at"]


class CoverageCostToBeneficiarySerializer(WritableNestedModelSerializer):
    """Coverage Cost To Beneficiary Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    category = CodeableConceptSerializer(many=False, required=False)
    network = CodeableConceptSerializer(many=False, required=False)
    unit = CodeableConceptSerializer(many=False, required=False)
    term = CodeableConceptSerializer(many=False, required=False)
    value_quantity = SimpleQuantitySerializer(many=False, required=False)
    value_money = MoneySerializer(many=False, required=False)
    exception = CoverageCostToBeneficiaryExceptionSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = CoverageCostToBeneficiary
        exclude = ["created_at", "updated_at"]


class CoverageClassSerializer(WritableNestedModelSerializer):
    """Coverage Class Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    value = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = CoverageClass
        exclude = ["created_at", "updated_at"]


class CoverageSerializer(BaseWritableNestedModelSerializer):
    """Coverage Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    payment_by = CoveragePaymentBySerializer(required=False)
    type = CodeableConceptSerializer(required=False)
    policy_holder = CoveragePolicyHolderReferenceSerializer(required=False)
    subscriber = PatientRelatedPersonReferenceSerializer(required=False)
    subscriber_identifier = IdentifierSerializer(required=False, many=True)
    beneficiary = PatientReferenceSerializer(required=False)
    relationship = CodeableConceptSerializer(required=False)
    period = PeriodSerializer(required=False)
    insurer = OrganizationReferenceSerializer(required=False)
    klass = CoverageClassSerializer(required=False, many=True)
    cost_to_beneficiary = CoverageCostToBeneficiarySerializer(required=False, many=True)
    contract = ContractReferenceSerializer(required=False, many=True)

    class Meta:
        """Meta class."""

        model = Coverage
        exclude = ["created_at", "updated_at"]
        rename_fields = {
            "class": "klass",
            "subscriber_id": "subscriber_identifier",
        }


class CoverageReferenceSerializer(BaseReferenceModelSerializer):
    """Coverage reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = CoverageReference
        exclude = ["created_at", "updated_at"]


class CoverageClaimResponseReferenceSerializer(BaseReferenceModelSerializer):
    """coverage claim response reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """meta options."""

        model = CoverageClaimResponseReference
        exclude = ["created_at", "updated_at"]



"""diagnostic report choices."""

from django.db.models import TextChoices
from django.utils.translation import gettext_lazy as _


class SupportingInfoChoices(TextChoices):
    """Supporting info choices."""

    QUESTION = "question", _("Question")
    RESULT = "result", _("Result")
    SUPPORTING_CLINICAL_INFORMATION = (
        "supporting_clinical_information",
        _("Supporting Clinical Information"),
    )


class DiagnosticReportStatus(TextChoices):
    """diagnostic report status choices."""

    REGISTERED = "registered", _("Registered")
    PARTIAL = "partial", _("Partial")
    PRELIMINARY = "preliminary", _("Preliminary")
    MODIFIED = "modified", _("Modified")
    FINAL = "final", _("Final")
    AMENDED = "amended", _("Amended")
    CORRECTED = "corrected", _("Corrected")
    APPENDED = "appended", _("Appended")
    CANCELLED = "cancelled", _("Cancelled")
    ENTERED_IN_ERROR = "entered_in_error", _("Entered in Error")



"""body structure urls."""

from django.urls import path

from dfhir.bodystructures.views import BodyStructureDetailView, BodyStructureListView

app_name = "bodystructures"

urlpatterns = [
    path("bodystructures/", BodyStructureListView.as_view(), name="bodystructure-list"),
    path(
        "bodystructures/<int:pk>/",
        BodyStructureDetailView.as_view(),
        name="bodystructure-detail",
    ),
]



"""medication statements app."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class MedicationstatementsConfig(AppConfig):
    """medication statements app."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.medicationstatements"
    verbose_name = _("Medication Statements")



"""Procedures serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
    RangeSerializer,
    ReferenceSerializer,
    TimingSerializer,
)
from dfhir.bodystructures.serializers import BodyStructureReferenceSerializer
from dfhir.conditions.serializers import ConditionCodeableReferenceSerializer
from dfhir.devices.serializers import DeviceReferenceSerializer
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.locations.serializers import LocationReferenceSerializer
from dfhir.observations.serializers import ObservationCodeableReferenceSerializer
from dfhir.servicerequests.serializers import (
    ServiceRequestPlanDefinitionReferenceSerializer,
)

from .models import (
    Procedure,
    ProcedureBasedOnReference,
    ProcedureCodeableReference,
    ProcedureFocalDevice,
    ProcedureFocusReference,
    ProcedurePartOfReference,
    ProcedurePerformer,
    ProcedurePerformerActorReference,
    ProcedureReasonCodeableReference,
    ProcedureReasonReference,
    ProcedureRecorderReference,
    ProcedureReference,
    ProcedureReportedReference,
    ProcedureReportReference,
    ProcedureSubjectReference,
    ProcedureUsedCodeableReference,
    ProcedureUsedReference,
)


class ProcedureReportReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Report Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureReportReference
        exclude = ["created_at", "updated_at"]


class ProcedureBasedOnReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Based On Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureBasedOnReference
        exclude = ["created_at", "updated_at"]


class ProcedurePartOfReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Part Of Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedurePartOfReference
        exclude = ["created_at", "updated_at"]


class ProcedureSubjectReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Subject Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureSubjectReference
        exclude = ["created_at", "updated_at"]


class ProcedureReportedReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Reported Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureReportedReference
        exclude = ["created_at", "updated_at"]


class ProcedureRecorderReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Recorder Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureRecorderReference
        exclude = ["created_at", "updated_at"]


class ProcedureReasonReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Reason Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureReasonReference
        exclude = ["created_at", "updated_at"]


class ProcedureUsedReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Used Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureUsedReference
        exclude = ["created_at", "updated_at"]


class ProcedureFocusReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Focus Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureFocusReference
        exclude = ["created_at", "updated_at"]


class ProcedurePerformerActorReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Performer Actor Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedurePerformerActorReference
        exclude = ["created_at", "updated_at"]


class ProcedureFocalDeviceSerializer(WritableNestedModelSerializer):
    """Procedure Focal Device serializer."""

    action = CodeableConceptSerializer(required=False)
    manipulated = DeviceReferenceSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureFocalDevice
        exclude = ["created_at", "updated_at"]


class ProcedurePerformerSerializer(WritableNestedModelSerializer):
    """Procedure Performer serializer."""

    function = CodeableConceptSerializer(required=False)
    actor = ProcedurePerformerActorReferenceSerializer(required=False)
    on_behalf_of = OrganizationReferenceSerializer(required=False)
    period = PeriodSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedurePerformer
        exclude = ["created_at", "updated_at"]


class ProcedureReasonCodeableReferenceSerializer(WritableNestedModelSerializer):
    """Procedure Reason Codeable Reference serializer."""

    reference = ProcedureReasonReferenceSerializer(required=False)
    concept = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureReasonCodeableReference
        exclude = ["created_at", "updated_at"]


class ProcedureUsedCodeableReferenceSerializer(WritableNestedModelSerializer):
    """Procedure Used Codeable Reference serializer."""

    reference = ProcedureUsedReferenceSerializer(required=False)
    concept = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureUsedCodeableReference
        exclude = ["created_at", "updated_at"]


class ProcedureSerializer(BaseWritableNestedModelSerializer):
    """Procedure serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    based_on = ProcedureBasedOnReferenceSerializer(many=True, required=False)
    part_of = ProcedurePartOfReferenceSerializer(many=True, required=False)
    status_reason = CodeableConceptSerializer(required=False)
    category = CodeableConceptSerializer(many=True, required=False)
    code = CodeableConceptSerializer(required=False)
    subject = ProcedureSubjectReferenceSerializer(required=False)
    focus = ProcedureFocusReferenceSerializer(many=False, required=False)
    encounter = EncounterReferenceSerializer(required=False)
    occurrence_period = PeriodSerializer(required=False)
    occurrence_range = RangeSerializer(required=False)
    occurrence_timing = TimingSerializer(required=False)
    recorder = ProcedureRecorderReferenceSerializer(required=False)
    reported_reference = ProcedureReportedReferenceSerializer(required=False)
    performer = ProcedurePerformerSerializer(many=True, required=False)
    location = LocationReferenceSerializer(required=False, many=False)
    reason = ProcedureReasonCodeableReferenceSerializer(many=True, required=False)
    body_site = CodeableConceptSerializer(many=True, required=False)
    body_structure = BodyStructureReferenceSerializer(many=True, required=False)
    outcome = ObservationCodeableReferenceSerializer(many=True, required=False)
    report = ProcedureReportReferenceSerializer(many=True, required=False)
    complication = ConditionCodeableReferenceSerializer(many=True, required=False)
    follow_up = ServiceRequestPlanDefinitionReferenceSerializer(
        many=True, required=False
    )
    note = AnnotationSerializer(many=True, required=False)
    focal_device = ProcedureFocalDeviceSerializer(many=True, required=False)
    used = ProcedureUsedCodeableReferenceSerializer(many=True, required=False)
    supporting_info = ReferenceSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = Procedure
        exclude = ["created_at", "updated_at"]


class ProcedureReferenceSerializer(BaseReferenceModelSerializer):
    """Procedure Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ProcedureReference
        exclude = ["created_at", "updated_at"]


class ProcedureCodeableReferenceSerializer(WritableNestedModelSerializer):
    """Procedure Codeable Reference serializer."""

    reference = ProcedureReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ProcedureCodeableReference
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.contrib.postgres.fields
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('healthcareservices', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('schedules', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Slot',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('appointment_type', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(choices=[('walk-in', 'Walk-in'), ('routine', 'Routine'), ('checkup', 'Check-up'), ('followup', 'Follow-up'), ('emergency', 'Emergency')], max_length=255), null=True, size=None)),
                ('start', models.DateTimeField(null=True)),
                ('end', models.DateTimeField(null=True)),
                ('overbooked', models.BooleanField(default=False)),
                ('comment', models.TextField(null=True)),
                ('status', models.CharField(choices=[('free', 'Free'), ('busy', 'Busy'), ('busy_unavailable', 'Busy Unavailable'), ('busy_tentative', 'Busy Tentative'), ('enter_in_error', 'Enter in Error')], default='free', max_length=255)),
                ('identifier', models.ManyToManyField(blank=True, related_name='slot_identifier', to='base.identifier')),
                ('practitioner', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='slot_practitioner', to='practitioners.practitioner')),
                ('schedule', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='slot_schedule', to='schedules.schedule')),
                ('service_category', models.ManyToManyField(blank=True, related_name='slot_service_category', to='base.codeableconcept')),
                ('service_type', models.ManyToManyField(blank=True, related_name='slot_service_type', to='healthcareservices.healthcareservicecodeablereference')),
                ('specialty', models.ManyToManyField(blank=True, related_name='slot_specialty', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SlotReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='slot_reference_identifier', to='base.identifier')),
                ('slot', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='slot_reference_slot', to='slots.slot')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('bodystructures', '0002_initial'),
        ('claimresponses', '0002_initial'),
        ('claims', '0002_initial'),
        ('locations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claimresponse',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='payee_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='pre_auth_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_request', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='provider_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponse',
            name='add_item',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item', to='claimresponses.claimresponseadditem'),
        ),
        migrations.AddField(
            model_name='claimresponseadditembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site_body_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='claimresponseadditembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_body_site', to='claimresponses.claimresponseadditembodysite'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail', to='claimresponses.claimresponseadditemdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_detail_sub_detail', to='claimresponses.claimresponseadditemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_organization', to='base.organizationreference'),
        ),
    ]



"""molecular definitions views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.moleculardefinitions.models import MolecularDefinition
from dfhir.moleculardefinitions.serializers import MolecularDefinitionSerializer


class MolecularDefinitionListView(APIView):
    """molecular definitions list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: MolecularDefinitionSerializer(many=True)})
    def get(self, request):
        """Get molecular definitions."""
        molecular_definitions = MolecularDefinition.objects.all()
        serializer = MolecularDefinitionSerializer(molecular_definitions, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=MolecularDefinitionSerializer,
        responses={201: MolecularDefinitionSerializer},
    )
    def post(self, request):
        """Create a new molecular definition."""
        serializer = MolecularDefinitionSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class MolecularDefinitionDetailView(APIView):
    """molecular definitions detail view."""

    def get_object(self, pk):
        """Get molecular definition object."""
        try:
            return MolecularDefinition.objects.get(pk=pk)
        except MolecularDefinition.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: MolecularDefinitionSerializer})
    def get(self, request, pk=None):
        """Get molecular definition."""
        molecular_definition = self.get_object(pk)
        serializer = MolecularDefinitionSerializer(molecular_definition)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: MolecularDefinitionSerializer})
    def patch(self, request, pk=None):
        """Update molecular definition."""
        molecular_definition = self.get_object(pk)
        serializer = MolecularDefinitionSerializer(
            molecular_definition, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk=None):
        """Delete molecular definition."""
        molecular_definition = self.get_object(pk)
        molecular_definition.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""tasks urls."""

from django.urls import path

from dfhir.tasks import views

app_name = "tasks"

urlpatterns = [
    path("tasks/", views.TaskListView.as_view(), name="task-list"),
    path("tasks/<int:pk>/", views.TaskDetailView.as_view(), name="task-detail"),
]



"""imaging selections model choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class ImagingSelectionInstanceImageRegion2DRegionTypeChoices(models.TextChoices):
    """Imaging Selection Instance Image Region Type Choices."""

    POINT = "point", _("Point")
    POLYLINE = "polyline", _("Polyline")
    MULTIPOINT = "multipoint", _("Multipoint")
    CIRCLE = "circle", _("Circle")
    ELLIPSE = "ellipse", _("Ellipse")


class ImagingSelectionInstanceImageRegion3DRegionTypeChoices(models.TextChoices):
    """Imaging Selection Instance Image Region Type Choices."""

    POINT = "point", _("Point")
    MULTIPOINT = "multipoint", _("Multipoint")
    POLYLINE = "polyline", _("Polyline")
    POLYGON = "polygon", _("Polygon")
    ELLIPSE = "ellipse", _("Ellipse")
    ELLIPSOID = "ellipsoid", _("Ellipsoid")


class ImagingSelectionStatusChoices(models.TextChoices):
    """Imaging Selection Status Choices."""

    AVAILABLE = "available", _("Available")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")
    INACTIVE = "inactive", _("Inactive")
    UNKNOWN = "unknown", _("Unknown")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('allergyintolerances', '0001_initial'),
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allergyintolerance',
            name='clinical_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_clinical_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='allergyintolerance',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='allergy_intolerance_code', to='base.codeableconcept'),
        ),
    ]



"""medication requests urls."""

from django.urls import path

from dfhir.medicationrequests.views import (
    AdditionalIllustrationList,
    DosageMethodList,
    DosageRouteList,
    DosageSiteList,
    MediationRequestReferenceTypeList,
    MedicationRequestCategoryList,
    MedicationRequestDetail,
    MedicationRequestList,
    MedicationRequestMedicationCodeList,
    MedicationRequestReasonList,
    ReferenceAsNeededForList,
)

app_name = "medicationrequests"

urlpatterns = [
    path(
        "medicationrequests/",
        MedicationRequestList.as_view(),
        name="medicationrequest-list",
    ),
    path(
        "medicationrequests/<int:pk>/",
        MedicationRequestDetail.as_view(),
        name="medicationrequest-detail",
    ),
    path(
        "medicationrequests/reference-type/",
        MediationRequestReferenceTypeList.as_view(),
        name="medicationrequest-reference-type-list",
    ),
    path(
        "medicationrequests/category/",
        MedicationRequestCategoryList.as_view(),
        name="medicationrequest-category-list",
    ),
    path(
        "medicationrequests/reason/",
        MedicationRequestReasonList.as_view(),
        name="medicationrequest-reason-list",
    ),
    path(
        "medicationrequests/medication-code/",
        MedicationRequestMedicationCodeList.as_view(),
        name="medicationrequest-medication-code-list",
    ),
    path(
        "medicationrequests/dosage-method/",
        DosageMethodList.as_view(),
        name="medicationrequest-dosage-method-list",
    ),
    path(
        "medicationrequests/dosage-route/",
        DosageRouteList.as_view(),
        name="medicationrequest-dosage-route-list",
    ),
    path(
        "medicationrequests/dosage-site/",
        DosageSiteList.as_view(),
        name="medicationrequest-dosage-site-list",
    ),
    path(
        "medicationrequests/additional-illustration/",
        AdditionalIllustrationList.as_view(),
        name="medicationrequest-additional-illustration-list",
    ),
    path(
        "medicationrequests/as-needed-for/",
        ReferenceAsNeededForList.as_view(),
        name="medicationrequest-as-needed-for-list",
    ),
]



"""Organizations app configuration."""

import contextlib

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class OrganizationsConfig(AppConfig):
    """Organizations app config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.organizations"
    verbose_name = _("Organizations")

    def ready(self):
        """Import signals."""
        with contextlib.suppress(ImportError):
            import dfhir.organizations.signals  # noqa: F401



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('biologicallyderivedproducts', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_request', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='storage_temp_requirements',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_storage_temp_requirements', to='base.range'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='collected_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_collected_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='collector',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_collector', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductcollection',
            name='source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_collections_source', to='patients.patientorganizationreference'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='collection',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_products_collection', to='biologicallyderivedproducts.biologicallyderivedproductcollection'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductproperty',
            name='value_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_properties_value_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='property',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_property', to='biologicallyderivedproducts.biologicallyderivedproductproperty'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_reference_biologically_derived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='biologically_derived_product_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='biologicallyderivedproduct',
            name='parent',
            field=models.ManyToManyField(blank=True, related_name='biologically_derived_products_parent', to='biologicallyderivedproducts.biologicallyderivedproductreference'),
        ),
    ]



"""task views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.tasks.models import Task
from dfhir.tasks.serializers import TaskSerializer


class TaskListView(APIView):
    """task list view."""

    permission_classes = [AllowAny]

    @extend_schema(
        responses={200: TaskSerializer(many=True)},
    )
    def get(self, request):
        """Get all tasks."""
        tasks = Task.objects.all()
        serializer = TaskSerializer(tasks, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=TaskSerializer, responses={201: TaskSerializer})
    def post(self, request):
        """Create a task."""
        serializer = TaskSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class TaskDetailView(APIView):
    """task detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get task object."""
        try:
            return Task.objects.get(pk=pk)
        except Task.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(
        responses={200: TaskSerializer},
    )
    def get(self, request, pk):
        """Get task."""
        task = self.get_object(pk)
        serializer = TaskSerializer(task)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=TaskSerializer,
        responses={200: TaskSerializer},
    )
    def patch(self, request, pk):
        """Update task."""
        task = self.get_object(pk)
        serializer = TaskSerializer(task, data=request.data, partial=True)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        responses={204: None},
    )
    def delete(self, request, pk):
        """Delete task."""
        task = self.get_object(pk)
        task.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""supply delivery choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class SupplyDeliveryStatusChoices(models.TextChoices):
    """supply delivery status choices."""

    IN_PROGRESS = "in-progress", _("In Progress")
    COMPLETED = "completed", _("Completed")
    ABANDONED = "abandoned", _("Abandoned")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered In Error")



"""medication knowledge choices."""

from django.db.models import TextChoices
from django.utils.translation import gettext_lazy as _


class MedicationKnowledgeStatusChoices(TextChoices):
    """Medication knowledge status choices."""

    DRAFT = "draft", _("Draft")
    ACTIVE = "active", _("Active")
    RETIRED = "retired", _("Retired")
    UNKNOWN = "unknown", _("Unknown")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('adverseevents', '0002_initial'),
        ('allergyintolerances', '0002_initial'),
        ('base', '0003_initial'),
        ('conditions', '0001_initial'),
        ('devices', '0001_initial'),
        ('deviceusages', '0001_initial'),
        ('documentreferences', '0001_initial'),
        ('encounters', '0001_initial'),
        ('locations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='adverseevent',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_location', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='outcome',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='resulting_effect',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_resulting_effect', to='conditions.conditionobservationcodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='seriousness',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='adverse_event_seriousness', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='adverseevent',
            name='contributing_factor',
            field=models.ManyToManyField(blank=True, related_name='adverse_event_contributing_factor', to='adverseevents.adverseeventcontributingfactorcodeablereference'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='allergy_intolerance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_allergy_intolerance', to='allergyintolerances.allergyintolerance'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='device_usage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_device_usage', to='deviceusages.deviceusage'),
        ),
        migrations.AddField(
            model_name='adverseeventcontributingfactorreference',
            name='document_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='adverse_event_contributing_factor_reference_document_reference', to='documentreferences.documentreference'),
        ),
    ]



"""Goals views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import Goal
from .serializers import GoalSerializer


class GoalListView(APIView):
    """Goal list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: GoalSerializer(many=True)})
    def get(self, request):
        """Get all goals."""
        goals = Goal.objects.all()
        serializer = GoalSerializer(goals, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=GoalSerializer, responses={201: GoalSerializer})
    def post(self, request):
        """Create goal."""
        serializer = GoalSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class GoalDetailView(APIView):
    """Goal detail view."""

    def get_object(self, pk):
        """Get a goal object by ID."""
        try:
            return Goal.objects.get(pk=pk)
        except Goal.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: GoalSerializer})
    def get(self, request, pk):
        """Get a goal."""
        goal = self.get_object(pk)
        serializer = GoalSerializer(goal)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=GoalSerializer, responses={200: GoalSerializer})
    def patch(self, request, pk):
        """Update a goal."""
        goal = self.get_object(pk)
        serializer = GoalSerializer(goal, data=request.data, partial=True)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete a goal."""
        goal = self.get_object(pk)
        goal.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Allergy intolerances URLs."""

from django.urls import path

from . import views

app_name = "allergyintolerances"


urlpatterns = [
    path(
        "allergyintolerances/",
        views.AllergyIntoleranceListView.as_view(),
        name="allergyintolerance-list-create",
    ),
    path(
        "allergyintolerances/<int:pk>/",
        views.AllergyIntoleranceDetailView.as_view(),
        name="allergyintolerance-retrieve-update-destroy",
    ),
]



"""Views for the conditions app."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.conditions.models import Condition
from dfhir.conditions.serializers import ConditionSerializer


class ConditionListView(APIView):
    """condition list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: ConditionSerializer(many=True)})
    def get(self, request):
        """Get all conditions."""
        conditions = Condition.objects.all()
        serializer = ConditionSerializer(conditions, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=ConditionSerializer, responses={201: ConditionSerializer})
    def post(self, request):
        """Create a new condition."""
        serializer = ConditionSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class ConditionDetailView(APIView):
    """Condition detail view."""

    def get_object(self, pk):
        """Get condition object."""
        try:
            return Condition.objects.get(pk=pk)
        except Condition.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: ConditionSerializer})
    def get(self, request, pk):
        """Get condition."""
        condition = self.get_object(pk)
        serializer = ConditionSerializer(condition)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(request=ConditionSerializer, responses={200: ConditionSerializer})
    def patch(self, request, pk):
        """Update condition."""
        condition = self.get_object(pk)
        serializer = ConditionSerializer(condition, data=request.data, partial=True)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete condition."""
        condition = self.get_object(pk)
        condition.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""groups serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CodingSerializer,
    ContactDetailSerializer,
    ExpressionSerializer,
    IdentifierSerializer,
    PeriodSerializer,
    QuantitySerializer,
    RangeSerializer,
    ReferenceSerializer,
    RelativeTimeSerializer,
    UsageContextSerializer,
)

from .models import (
    Group,
    GroupCharacteristic,
    GroupCharacteristicDeterminedByReference,
    GroupManagingEntityReference,
    GroupMember,
    GroupMemberEntityReference,
    GroupReference,
)


class GroupCharacteristicDeterminedByReferenceSerializer(BaseReferenceModelSerializer):
    """Group Characteristic Determined By Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = GroupCharacteristicDeterminedByReference
        exclude = ["created_at", "updated_at"]


class GroupCharacteristicSerializer(WritableNestedModelSerializer):
    """Group Characteristic Serializer."""

    code = CodeableConceptSerializer(many=False, required=False)
    value_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    value_quantity = QuantitySerializer(many=False, required=False)
    value_range = RangeSerializer(many=False, required=False)
    value_reference = ReferenceSerializer(many=False, required=False)
    value_expression = ExpressionSerializer(many=False, required=False)
    valueRange = RangeSerializer(many=False, required=False)
    valueExpression = ExpressionSerializer(many=False, required=False)
    method = CodeableConceptSerializer(many=True, required=False)
    determined_by_reference = GroupCharacteristicDeterminedByReferenceSerializer(
        many=False, required=False
    )
    determined_by_expression = ExpressionSerializer(many=False, required=False)
    offset = CodeableConceptSerializer(many=False, required=False)
    instances_quantity = QuantitySerializer(many=False, required=False)
    instances_range = RangeSerializer(many=False, required=False)
    duration_duration = QuantitySerializer(many=False, required=False)
    duration_range = RangeSerializer(many=False, required=False)
    period = PeriodSerializer(many=False, required=False)
    timing = RelativeTimeSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = GroupCharacteristic
        exclude = ["created_at", "updated_at"]


class GroupManagingEntityReferenceSerializer(BaseReferenceModelSerializer):
    """Group Managing Entity Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = GroupManagingEntityReference
        exclude = ["created_at", "updated_at"]


class GroupMemberEntityReferenceSerializer(BaseReferenceModelSerializer):
    """Group Member Entity Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = GroupMemberEntityReference
        exclude = ["created_at", "updated_at"]


class GroupMemberSerializer(WritableNestedModelSerializer):
    """Group Member Serializer."""

    entity = GroupMemberEntityReferenceSerializer(many=False, required=False)
    involvement = CodeableConceptSerializer(many=True, required=False)
    period = PeriodSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = GroupMember
        exclude = ["created_at", "updated_at"]


class GroupSerializer(BaseWritableNestedModelSerializer):
    """Group Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    version_algorithm_coding = CodingSerializer(many=False, required=False)
    contact = ContactDetailSerializer(many=True, required=False)
    use_context = UsageContextSerializer(many=True, required=False)
    code = CodeableConceptSerializer(many=False, required=False)
    characteristic = GroupCharacteristicSerializer(many=True, required=False)
    managing_entity = GroupManagingEntityReferenceSerializer(many=False, required=False)
    member = GroupMemberSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = Group
        exclude = ["created_at", "updated_at"]


class GroupReferenceSerializer(BaseReferenceModelSerializer):
    """Group Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = GroupReference
        exclude = ["created_at", "updated_at"]



"""Charge items models."""

from django.contrib.postgres.fields import ArrayField
from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    Identifier,
    OrganizationReference,
    TimeStampedModel,
)
from dfhir.chargeitems.choices import ChargeItemStatusChoice


class ChargeItemReference(BaseReference):
    """Charge item reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reference_identifier",
    )
    charge_item = models.ForeignKey(
        "ChargeItem",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reference_charge_item",
    )


class ChargeItemPerformerActorReference(BaseReference):
    """charge item performer actor reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_identifier",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_practitioner",
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_practitioner_role",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_organization",
    )
    healthcare_service = models.ForeignKey(
        "healthcareservices.HealthcareService",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_healthcare_service",
    )
    care_team = models.ForeignKey(
        "careteams.CareTeam",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_care_team",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_patient",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_device",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor_reference_related_person",
    )


class ChargeItemPerformer(TimeStampedModel):
    """Charge item performer model."""

    function = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_function",
    )
    actor = models.ForeignKey(
        ChargeItemPerformerActorReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performer_actor",
    )


class ChargeItemEntererReference(BaseReference):
    """Charge item enterer reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_identifier",
    )
    condition = models.ForeignKey(
        "conditions.Condition",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_condition",
    )
    diagnostic_report = models.ForeignKey(
        "diagnosticreports.DiagnosticReport",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_diagnostic_report",
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_observation",
    )
    immunization_recommendation = models.ForeignKey(
        "immunizationrecommendations.ImmunizationRecommendation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_immunization_recommendation",
    )
    procedure = models.ForeignKey(
        "procedures.Procedure",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer_reference_procedure",
    )


class ChargeItemServiceReference(BaseReference):
    """Charge item service reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_identifier",
    )
    diagnostic_report = models.ForeignKey(
        "diagnosticreports.DiagnosticReport",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_diagnostic_report",
    )
    imaging_study = models.ForeignKey(
        "imagingstudies.ImagingStudy",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_imaging_study",
    )
    immunization = models.ForeignKey(
        "immunizations.Immunization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_immunization",
    )
    medication_administration = models.ForeignKey(
        "medicationadministrations.MedicationAdministration",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_medication_administration",
    )
    medication_dispense = models.ForeignKey(
        "medicationdispenses.MedicationDispense",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_medication_dispense",
    )
    medication_request = models.ForeignKey(
        "medicationrequests.MedicationRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_medication_request",
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_observation",
    )
    procedure = models.ForeignKey(
        "procedures.Procedure",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_procedure",
    )
    service_request = models.ForeignKey(
        "servicerequests.ServiceRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_service_request",
    )
    supply_delivery = models.ForeignKey(
        "supplydeliveries.SupplyDelivery",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_reference_supply_delivery",
    )


class ChargeItemServiceCodealbeReference(TimeStampedModel):
    """Charge item service codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        ChargeItemServiceReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_service_codeable_reference_reference",
    )


class ChargeItemProductReference(BaseReference):
    """Charge item product reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_reference_identifier",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_reference_device",
    )
    medication = models.ForeignKey(
        "medications.Medication",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_reference_medication",
    )
    substance = models.ForeignKey(
        "substances.Substance",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_reference_substance",
    )


class ChargeItemProductCodeableReference(TimeStampedModel):
    """Charge item product codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        ChargeItemProductReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_product_codeable_reference_reference",
    )


class ChargeItemReasonReference(BaseReference):
    """Charge item reason reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_identifier",
    )
    condition = models.ForeignKey(
        "conditions.Condition",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_condition",
    )
    diagnostic_report = models.ForeignKey(
        "diagnosticreports.DiagnosticReport",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_diagnostic_report",
    )
    observation = models.ForeignKey(
        "observations.Observation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_observation",
    )
    immunization_recommendation = models.ForeignKey(
        "immunizationrecommendations.ImmunizationRecommendation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_immunization_recommendation",
    )
    procedure = models.ForeignKey(
        "procedures.Procedure",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_reference_procedure",
    )


class ChargeItemReasonCodeableReference(TimeStampedModel):
    """Charge item reason codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        ChargeItemReasonReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_reason_codeable_reference_reference",
    )


class ChargeItem(TimeStampedModel):
    """Charge item model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="charge_item_identifier", blank=True
    )
    definition_uri = ArrayField(models.URLField(null=True), null=True)
    # TODO: definition_canonical = models.ForeignKey(ChargeItemDefinitionReference, on_delete=models.DO_NOTHING, null=True, related_name="charge_item_definition_reference_canonical")
    status = models.CharField(
        max_length=255, null=True, choices=ChargeItemStatusChoice.choices
    )
    part_of = models.ManyToManyField(
        ChargeItemReference,
        blank=True,
        related_name="charge_item_reference_part_of",
    )
    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_code",
    )
    subject = models.ForeignKey(
        "patients.PatientGroupReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_subject",
    )
    encounter = models.ForeignKey(
        "encounters.EncounterReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_encounter",
    )
    occurrence_date_time = models.DateTimeField(null=True)
    occurrence_period = models.ForeignKey(
        "base.Period",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_occurrence_period",
    )
    occurrence_timing = models.ForeignKey(
        "base.Timing",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_occurrence_timing",
    )
    performer = models.ManyToManyField(
        ChargeItemPerformer,
        blank=True,
        related_name="charge_item_performer",
    )
    performing_organization = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_performing_organization",
    )
    requesting_organization = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_requesting_organization",
    )
    cost_center = models.ForeignKey(
        OrganizationReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_cost_center",
    )
    quantity = models.ForeignKey(
        "base.Quantity",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_quantity",
    )
    body_site = models.ManyToManyField(
        CodeableConcept,
        blank=True,
        related_name="charge_item_body_site",
    )
    unit_price_component = models.ForeignKey(
        "base.MonetaryComponent",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_unit_price_component",
    )

    total_price_component = models.ForeignKey(
        "base.MonetaryComponent",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_total_price_component",
    )

    override_reason = models.ForeignKey(
        "base.CodeableConcept",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_override_reason",
    )
    enterer = models.ForeignKey(
        ChargeItemEntererReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="charge_item_enterer",
    )
    entered_date = models.DateTimeField(null=True)
    reason = models.ManyToManyField(
        ChargeItemReasonCodeableReference, blank=True, related_name="charge_item_reason"
    )
    service = models.ManyToManyField(
        ChargeItemServiceCodealbeReference,
        blank=True,
        related_name="charge_item_service",
    )
    product = models.ManyToManyField(
        ChargeItemProductCodeableReference,
        blank=True,
        related_name="charge_item_product",
    )
    account = models.ManyToManyField(
        "accounts.AccountReference",
        blank=True,
        related_name="charge_item_account",
    )
    note = models.ManyToManyField(
        "base.Annotation", blank=True, related_name="charge_item_note"
    )
    supporting_information = models.ManyToManyField(
        "base.Reference", blank=True, related_name="charge_item_supporting_information"
    )



"""Contract urls."""

from django.urls import path

from . import views

app_name = "contracts"

urlpatterns = [
    path("contracts/", views.ContractListView.as_view()),
    path("contracts/<int:pk>/", views.ContractDetailView.as_view()),
]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0001_initial'),
        ('appointments', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointmentresponse',
            name='appointment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_appointment', to='appointments.appointmentreference'),
        ),
    ]



"""Device models."""

from django.db import models

from dfhir.base.models import (
    Annotation,
    Attachment,
    BaseReference,
    CodeableConcept,
    ContactPoint,
    Identifier,
    OrganizationReference,
    Quantity,
    Range,
    TimeStampedModel,
)

from . import choices


class DeviceUdiCarrier(TimeStampedModel):
    """Device UDI carrier model."""

    device_identifier = models.CharField(max_length=255, null=True)
    device_identifier_system = models.CharField(max_length=255, null=True)
    carrier_hrft = models.CharField(max_length=255, null=True)
    carrier_aidc = models.CharField(max_length=255, null=True)
    issuer = models.CharField(max_length=255, null=True)
    jurisdiction = models.CharField(max_length=255, null=True)
    carrier = models.CharField(max_length=255, null=True)
    entry_type = models.CharField(max_length=255, null=True)


class DeviceName(TimeStampedModel):
    """Device name model."""

    value = models.CharField(max_length=255, null=True)
    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_name_type",
    )
    display = models.BooleanField(null=True, default=False)


class DeviceVersion(TimeStampedModel):
    """Device version model."""

    value = models.CharField(max_length=255, null=True)
    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_version_type",
    )
    component = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_version_component",
    )
    install_date = models.DateTimeField(null=True)


class DeviceConformsTo(TimeStampedModel):
    """Device conforms to model."""

    category = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_conforms_to_category",
    )
    specification = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_conforms_to_specification",
    )
    version = models.CharField(max_length=255, null=True)


class DeviceProperty(TimeStampedModel):
    """Device property model."""

    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_property_type",
    )
    value_codeable_concept = models.ForeignKey(
        CodeableConcept,
        related_name="device_property_value_code",
        on_delete=models.CASCADE,
        null=True,
    )
    value_string = models.CharField(max_length=255, null=True)
    value_boolean = models.BooleanField(null=True)
    value_integer = models.IntegerField(null=True)
    value_quantity = models.ForeignKey(
        Quantity,
        related_name="device_property_value_quantity",
        on_delete=models.CASCADE,
        null=True,
    )
    value_range = models.ForeignKey(
        Range,
        related_name="device_property_value_range",
        on_delete=models.CASCADE,
        null=True,
    )
    value_attachment = models.ForeignKey(
        Attachment,
        related_name="device_property_value_attachment",
        on_delete=models.CASCADE,
        null=True,
    )


class Device(TimeStampedModel):
    """Device model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="devices_identifier", blank=True
    )
    definition = models.ForeignKey(
        "devicedefinitions.DeviceDefinitionReference",
        on_delete=models.CASCADE,
        null=True,
    )
    status = models.CharField(
        max_length=255, choices=choices.DeviceStatus.choices, null=True
    )
    udi_carrier = models.ManyToManyField(DeviceUdiCarrier, blank=True)
    availability_status = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="devices_availability_status",
        null=True,
    )
    biological_source_event = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        null=True,
        related_name="devices_biological_source_event",
    )
    manufacturer = models.CharField(max_length=255, null=True)
    manufacture_date = models.DateTimeField(null=True)
    expiration_date = models.DateTimeField(null=True)
    lot_number = models.CharField(max_length=255, null=True)
    serial_number = models.CharField(max_length=255, null=True)
    name = models.ManyToManyField(DeviceName, related_name="devices_name", blank=True)
    model_number = models.CharField(max_length=255, null=True)
    part_number = models.CharField(max_length=255, null=True)
    category = models.ManyToManyField(
        CodeableConcept, related_name="devices_category", blank=True
    )
    type = models.ManyToManyField(
        CodeableConcept, related_name="devices_type", blank=True
    )
    device_version = models.ManyToManyField(
        DeviceVersion, related_name="devices_device_version", blank=True
    )
    conforms_to = models.ManyToManyField(
        DeviceConformsTo, related_name="devices_conforms_to", blank=True
    )
    property = models.ManyToManyField(
        DeviceProperty, related_name="devices_property", blank=True
    )
    mode = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        related_name="devices_mode",
        null=True,
    )
    cycle = models.IntegerField(null=True)
    duration = models.ForeignKey(
        Quantity, on_delete=models.CASCADE, related_name="devices_duration", null=True
    )
    owner = models.ForeignKey(
        OrganizationReference,
        on_delete=models.CASCADE,
        related_name="devices_owner",
        null=True,
    )
    contact = models.ManyToManyField(
        ContactPoint, related_name="devices_contact", blank=True
    )
    location = models.ForeignKey(
        "locations.LocationReference",
        on_delete=models.CASCADE,
        related_name="devices_location",
        null=True,
    )
    url = models.URLField(null=True)
    endpoint = models.ForeignKey(
        "endpoints.EndpointReference",
        on_delete=models.CASCADE,
        related_name="devices_endpoint",
        null=True,
    )
    gateway = models.ManyToManyField(
        "DeviceCodeableReference", related_name="devices_gateway", blank=True
    )
    note = models.ManyToManyField(Annotation, related_name="devices_note", blank=True)
    safety = models.ManyToManyField(
        CodeableConcept, related_name="devices_safety", blank=True
    )
    parent = models.ForeignKey(
        "DeviceReference",
        on_delete=models.CASCADE,
        related_name="devices_parent",
        null=True,
    )


class DeviceReference(BaseReference):
    """Device reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        null=True,
    )
    device = models.ForeignKey(
        Device,
        on_delete=models.CASCADE,
        null=True,
    )


class DeviceCodeableReference(TimeStampedModel):
    """device codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_codeable_reference_concept",
    )
    reference = models.ForeignKey(
        DeviceReference,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_codeable_reference_reference",
    )
    identifier = models.ForeignKey(
        Identifier,
        related_name="device_reference_identifier",
        on_delete=models.CASCADE,
        null=True,
    )
    device = models.ForeignKey(
        Device,
        related_name="device_reference_device",
        on_delete=models.CASCADE,
        null=True,
    )


class DeviceDeviceMetricReference(BaseReference):
    """device device metric reference."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_metric_reference_identifier",
    )
    device = models.ForeignKey(
        Device,
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_metric_reference_device",
    )
    device_metric = models.ForeignKey(
        "devicemetrics.DeviceMetric",
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_metric_reference_device_metric",
    )


class DeviceDeviceDefinitionReference(BaseReference):
    """device device definition reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_definition_reference_identifier",
    )
    device = models.ForeignKey(
        Device,
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_definition_reference_device",
    )
    device_definition = models.ForeignKey(
        "devicedefinitions.DeviceDefinition",
        on_delete=models.SET_NULL,
        null=True,
        related_name="device_device_definition_reference_device_definition",
    )


class DeviceDeviceDefinitionCodeableReference(TimeStampedModel):
    """device device definition codeable reference model."""

    reference = models.ForeignKey(
        DeviceDeviceDefinitionReference,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_device_definition_codeable_reference_reference",
    )
    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.CASCADE,
        null=True,
        related_name="device_device_definition_codeable_reference_concept",
    )



"""Family member history serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.base.serializers import (
    AgeSerializer,
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    PeriodSerializer,
    RangeSerializer,
)
from dfhir.patients.serializers import PatientReferenceSerializer

from .models import (
    FamilyMemberHistory,
    FamilyMemberHistoryCondition,
    FamilyMemberHistoryParticipant,
    FamilyMemberHistoryParticipantActorReference,
    FamilyMemberHistoryProcedure,
    FamilyMemberHistoryReasonCodeableReference,
    FamilyMemberHistoryReasonReference,
)


class FamilyMemberHistoryReasonReferenceSerializer(BaseReferenceModelSerializer):
    """Family Member History Reason Reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryReasonReference
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistoryReasonCodeableReferenceSerializer(
    WritableNestedModelSerializer
):
    """Family Member History Reason Codeable Reference serializer."""

    concept = CodeableConceptSerializer(many=False, required=False)
    reference = FamilyMemberHistoryReasonReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryReasonCodeableReference
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistoryConditionSerializer(WritableNestedModelSerializer):
    """Family Member History Condition serializer."""

    code = CodeableConceptSerializer(many=False, required=False)
    outcome = CodeableConceptSerializer(many=False, required=False)
    onset_age = AgeSerializer(many=False, required=False)
    onset_range = RangeSerializer(many=False, required=False)
    onset_period = PeriodSerializer(many=False, required=False)
    note = AnnotationSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryCondition
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistoryParticipantActorReferenceSerializer(
    BaseReferenceModelSerializer
):
    """Family Member History Participant Actor Reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryParticipantActorReference
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistoryParticipantSerializer(WritableNestedModelSerializer):
    """Family Member History Participant serializer."""

    function = CodeableConceptSerializer(many=False, required=False)
    actor = FamilyMemberHistoryParticipantActorReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryParticipant
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistoryProcedureSerializer(WritableNestedModelSerializer):
    """Family Member History Procedure serializer."""

    code = CodeableConceptSerializer(many=False, required=False)
    outcome = CodeableConceptSerializer(many=False, required=False)
    performed_age = AgeSerializer(many=False, required=False)
    performed_range = RangeSerializer(many=False, required=False)
    performed_period = PeriodSerializer(many=False, required=False)
    note = AnnotationSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistoryProcedure
        exclude = ["created_at", "updated_at"]


class FamilyMemberHistorySerializer(BaseWritableNestedModelSerializer):
    """Family Member History serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    data_absent_reason = CodeableConceptSerializer(many=False, required=False)
    patient = PatientReferenceSerializer(many=False, required=False)
    participant = FamilyMemberHistoryParticipantSerializer(many=True, required=False)
    name = serializers.CharField(max_length=255, required=False)
    relationship = CodeableConceptSerializer(many=False, required=False)
    sex = CodeableConceptSerializer(many=False, required=False)
    born_period = PeriodSerializer(many=False, required=False)
    age_age = AgeSerializer(many=False, required=False)
    age_range = RangeSerializer(many=False, required=False)
    deceased_age = AgeSerializer(many=False, required=False)
    deceased_range = RangeSerializer(many=False, required=False)
    reason = FamilyMemberHistoryReasonCodeableReferenceSerializer(
        many=True, required=False
    )
    note = AnnotationSerializer(many=True, required=False)
    condition = FamilyMemberHistoryConditionSerializer(many=True, required=False)
    procedure = FamilyMemberHistoryProcedureSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = FamilyMemberHistory
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('encounters', '0002_initial'),
        ('endpoints', '0001_initial'),
        ('locations', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ImagingStudyBasedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudyProcedureReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudyReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudyReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudySeries',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('uid', models.CharField(max_length=255, null=True)),
                ('number', models.IntegerField(null=True)),
                ('description', models.CharField(max_length=255, null=True)),
                ('number_of_instances', models.IntegerField(null=True)),
                ('started', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudySeriesInstance',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('uid', models.CharField(max_length=255)),
                ('sop_class', models.CharField(max_length=255, null=True)),
                ('number', models.IntegerField(null=True)),
                ('title', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudySeriesPerformer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudySeriesPerformerActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudySubjectReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ImagingStudy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('registered', 'Registered'), ('available', 'Available'), ('cancelled', 'Cancelled'), ('entered-in-error', 'Entered in error'), ('unknown', 'Unknown'), ('inactive', 'Inactive')], max_length=255, null=True)),
                ('started', models.DateTimeField(null=True)),
                ('description', models.CharField(max_length=255, null=True)),
                ('number_of_series', models.IntegerField(null=True)),
                ('number_of_instances', models.IntegerField(null=True)),
                ('encounter', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_encounter', to='encounters.encounterreference')),
                ('endpoint', models.ManyToManyField(blank=True, related_name='imaging_study_endpoint', to='endpoints.endpointreference')),
                ('identifier', models.ManyToManyField(blank=True, related_name='imaging_study_identifier', to='base.identifier')),
                ('location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='imaging_study_location', to='locations.locationreference')),
                ('modality', models.ManyToManyField(blank=True, related_name='imaging_study_modality', to='base.codeableconcept')),
                ('note', models.ManyToManyField(blank=True, related_name='imaging_study_note', to='base.annotation')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
